.. include:: ../README.md

.. toctree::
   :caption: User Documentation
   :maxdepth: 2

   installing
   basics
   duet

.. toctree::
    :maxdepth: 2
    :caption: Developer Documentation

    dev_environment
    codebase_walkthrough
    finding_an_issue
    coding_standards
    joining_a_team

.. toctree::
    :maxdepth: 2
    :caption: API Documentation

    syft.ast <api/syft.ast>
    syft.core <api/syft.core>
    syft.decorators <api/syft.decorators>
    syft.grid <api/syft.grid>
    syft.lib <api/syft.lib>
    syft.proto <api/syft.proto>
